@@ -42,7 +42,6 @@
 #include "SessionManager.h"
 #include "ProfileManager.h"
 #include "ViewSplitter.h"
-#include "Enumeration.h"
 #include "ViewContainer.h"
 
 using namespace Konsole;
@@ -222,8 +221,10 @@ void ViewManager::setupActions()
     collection->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_Tab);
     connect(action, &QAction::triggered, this, &ViewManager::lastUsedViewReverse);
 
-    action = new QAction(i18nc("@action Shortcut entry", "Maximize current Terminal"), this);
-    collection->addAction(QStringLiteral("maximize-current-terminal"), action);
+    action = new QAction(i18nc("@action Shortcut entry", "Toggle maximize current view"), this);
+    action->setText(i18nc("@action:inmenu", "Toggle maximize current view"));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("view-fullscreen")));
+    collection->addAction(QStringLiteral("toggle-maximize-current-view"), action);
     collection->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_E);
     connect(action, &QAction::triggered, _viewContainer, &TabbedViewContainer::toggleMaximizeCurrentTerminal);
     _multiSplitterOnlyActions << action;
@@ -251,9 +252,12 @@ void ViewManager::setupActions()
         collection->addAction(QStringLiteral("switch-to-tab-%1").arg(i), action);
         _multiTabOnlyActions << action;
 
-        // only add default shortcut bindings for the first 9 tabs, regardless of SWITCH_TO_TAB_COUNT
+        // only add default shortcut bindings for the first 10 tabs, regardless of SWITCH_TO_TAB_COUNT
         if (i < 9) {
             collection->setDefaultShortcut(action, QStringLiteral("Alt+%1").arg(i + 1));
+        } else if (i == 9) {
+            // add shortcut for 10th tab
+            collection->setDefaultShortcut(action, Qt::ALT + Qt::Key_0);
         }
     }
 
@@ -529,7 +533,7 @@ void ViewManager::focusAnotherTerminal(ViewSplitter *toplevelSplitter)
     }
 }
 
-void ViewManager::viewActivated(TerminalDisplay *view)
+void ViewManager::activateView(TerminalDisplay *view)
 {
     Q_ASSERT(view != nullptr);
 
@@ -590,7 +594,7 @@ SessionController *ViewManager::createController(Session *session, TerminalDispl
     // create a new controller for the session, and ensure that this view manager
     // is notified when the view gains the focus
     auto controller = new SessionController(session, view, this);
-    connect(controller, &Konsole::SessionController::focused, this,
+    connect(controller, &Konsole::SessionController::viewFocused, this,
             &Konsole::ViewManager::controllerChanged);
     connect(session, &Konsole::Session::destroyed, controller,
             &Konsole::SessionController::deleteLater);
@@ -709,7 +713,7 @@ TabbedViewContainer *ViewManager::createContainer()
     connect(container, &Konsole::TabbedViewContainer::viewRemoved, this,
             &Konsole::ViewManager::viewDestroyed);
     connect(container, &Konsole::TabbedViewContainer::activeViewChanged, this,
-            &Konsole::ViewManager::viewActivated);
+            &Konsole::ViewManager::activateView);
 
     return container;
 }
@@ -761,7 +765,7 @@ ViewManager::NavigationMethod ViewManager::navigationMethod() const
 
 void ViewManager::containerViewsChanged(TabbedViewContainer *container)
 {
-    Q_UNUSED(container);
+    Q_UNUSED(container)
     // TODO: Verify that this is right.
     emit viewPropertiesChanged(viewProperties());
 }
@@ -1025,7 +1029,7 @@ QStringList ViewManager::sessionList()
 
 int ViewManager::currentSession()
 {
-    if (_pluggedController) {
+    if (_pluggedController != nullptr) {
         Q_ASSERT(_pluggedController->session() != nullptr);
         return _pluggedController->session()->sessionId();
     }
@@ -1083,6 +1087,16 @@ QString ViewManager::defaultProfile()
     return ProfileManager::instance()->defaultProfile()->name();
 }
 
+void ViewManager::setDefaultProfile(const QString &profileName)
+{
+    const QList<Profile::Ptr> profiles = ProfileManager::instance()->allProfiles();
+    for (const Profile::Ptr &profile : profiles) {
+        if (profile->name() == profileName) {
+            ProfileManager::instance()->setDefaultProfile(profile);
+        }
+    }
+}
+
 QStringList ViewManager::profileList()
 {
     return ProfileManager::instance()->availableProfileNames();
