@@ -284,6 +284,10 @@ public Q_SLOTS:
     // DBus slot that returns the name of default profile
     Q_SCRIPTABLE QString defaultProfile();
 
+    // TODO: its semantic is application-wide. Move it to more appropriate place
+    // DBus slot that sets the default profile
+    Q_SCRIPTABLE void setDefaultProfile(const QString &profile);
+
     // TODO: its semantic is application-wide. Move it to more appropriate place
     // DBus slot that returns a string list of defined (known) profiles
     Q_SCRIPTABLE QStringList profileList();
@@ -333,7 +337,7 @@ private Q_SLOTS:
 
     // called when the active view in a ViewContainer changes, so
     // that we can plug the appropriate actions into the UI
-    void viewActivated(TerminalDisplay *view);
+    void activateView(TerminalDisplay *view);
 
     void focusUp();
     void focusDown();
